=======================
DataFileStreamProcessor
=======================

.. autoclass:: openmsistream.DataFileStreamProcessor
   :private-members:
   :inherited-members:
   :exclude-members: _on_check, _on_shutdown, _run_worker, alive, consumer_group_id, get_argument_parser, get_new_subscribed_consumer, kafkacrypto, logger, progress_msg, run, shutdown, topic_name
